==> OSCA.multisample_1.1.0.tar.gz: OSCA.multisample/inst/doc/book/index.md <==
--- 
title: "Multi-Sample Single-Cell Analyses with Bioconductor"
documentclass: book
bibliography: ref.bib
biblio-style: apalike
link-citations: yes
favicon: "/home/biocbuild/bbs-3.14-bioc/R/library/rebook/images/favicon.ico"
github-repo: "LTLA/OSCA.multisample"
---



---
date: "**Authors:** Robert Amezquita [aut], Aaron Lun [aut, cre], Stephanie Hicks [aut], Raphael Gottardo [aut]<br/>
  **Version:** 1.1.0<br/>
  **Modified:** 2021-05-17<br/>
  **Compiled:** 2021-05-25<br/>
  **Environment:** R version 4.1.0 beta (2021-05-03 r80259), Bioconductor 3.14<br/>
  **License:** CC BY<br/>
  **Copyright:** Bioconductor, 2021<br/>
  **Source:** https://github.com/LTLA/OSCA.multisample"
url: "https://github.com/LTLA/OSCA.multisample"
---

# Welcome {-}

<a href="https://bioconductor.org"><img src="https://github.com/Bioconductor/BiocStickers/raw/master/Bioconductor/Bioconductor-serial.gif" width="200" alt="Bioconductor Sticker" align="right" style="margin: 0 1em 0 1em" /></a> 

This site contains the advanced analysis chapters for the [__"Orchestrating Single-Cell Analysis with Bioconductor"__ book](http://bioconductor.org/books/3.14/OSCA).
This describes the handling of multiple samples in a single-cell RNA-seq analysis, 
    starting with integration of multiple datasets into a common space for consistent analyses,
    differential expression comparisons between conditions based on pseudo-bulk samples,
    and differential abundance analyses for cell subpopulations. It is intended for readers who are already familiar with basic single-cell analyses, possibly after reading some of the prior books in this collection.

==> OSCA.multisample_1.4.2.tar.gz: OSCA.multisample/inst/doc/book/index.md <==
--- 
title: "Multi-Sample Single-Cell Analyses with Bioconductor"
documentclass: book
bibliography: ref.bib
biblio-style: apalike
link-citations: yes
favicon: "/home/biocbuild/bbs-3.15-bioc/R/library/rebook/images/favicon.ico"
github-repo: "OSCA-source/OSCA.multisample"
---



---
date: "**Authors:** Robert Amezquita [aut], Aaron Lun [aut, cre], Stephanie Hicks [aut], Raphael Gottardo [aut]<br/>
  **Version:** 1.4.2<br/>
  **Modified:** 2022-05-20<br/>
  **Compiled:** 2022-05-23<br/>
  **Environment:** R version 4.2.0 (2022-04-22), Bioconductor 3.15<br/>
  **License:** CC BY<br/>
  **Copyright:** Bioconductor, 2022<br/>
  **Source:** https://github.com/OSCA-source/OSCA.multisample"
url: "https://github.com/OSCA-source/OSCA.multisample"
---

# Welcome {-}

<a href="https://bioconductor.org"><img src="https://github.com/Bioconductor/BiocStickers/raw/master/Bioconductor/Bioconductor-serial.gif" width="200" alt="Bioconductor Sticker" align="right" style="margin: 0 1em 0 1em" /></a> 

This site contains the advanced analysis chapters for the [__"Orchestrating Single-Cell Analysis with Bioconductor"__ book](http://bioconductor.org/books/3.15/OSCA).
This describes the handling of multiple samples in a single-cell RNA-seq analysis, 
    starting with integration of multiple datasets into a common space for consistent analyses,
    differential expression comparisons between conditions based on pseudo-bulk samples,
    and differential abundance analyses for cell subpopulations. It is intended for readers who are already familiar with basic single-cell analyses, possibly after reading some of the prior books in this collection.
